# Basic plugin

This plugin is used for simple git projects when `PROGRAMMING_LANGUAGE` is set to `basic`.

## Release
Only basic git operations (tagging, version incrementation, changelog commit) are performed

## Documentation
N/A